#
# spec file for package rtkit
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           rtkit
Summary:        Realtime Policy and Watchdog Daemon
License:        GPL-3.0+ and BSD-3-Clause
Group:          System/Base
Version:        0.11_git201205151338
Release:        13.4
# The daemon itself is GPL v3 or later, the reference implementation for the client BSD-3-Clause
Source:         %{name}-%{version}.tar.xz
Url:            http://git.0pointer.de/?p=rtkit.git
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  automake
BuildRequires:  dbus-1-devel >= 1.2
BuildRequires:  libcap-devel
BuildRequires:  polkit-devel
BuildRequires:  xz
Requires:       polkit
PreReq:         dbus-1
%if 0%{?suse_version} > 1140
BuildRequires:  pkgconfig(libsystemd-daemon)
%{?systemd_requires}
%define has_systemd 1
%endif
Patch0:         rtkit-use-system-sd-daemon.patch
# PATCH-FIX-UPSTREAM rtkit-bnc836939.patch sreeves@suse.com -- use of insecure polkit DBUS API
Patch1:         rtkit-bnc836939.patch
Patch2:         rtkit-no-cpu-controlgroup.patch

%description
RealtimeKit is a D-Bus system service that changes the
scheduling policy of user processes/threads to SCHED_RR (i.e. realtime
scheduling mode) on request. It is intended to be used as a secure
mechanism to allow real-time scheduling to be used by normal user
processes.

%prep
%setup -q
%patch0 -p1
%patch1 -p1
%patch2 -p1

%build
autoreconf -fiv
%configure --disable-silent-rules \
%if 0%{?has_systemd}
--with-systemdsystemunitdir=%{_unitdir} \
%endif
--libexecdir=%{_libexecdir}/rtkit

make %{?_smp_mflags}
./rtkit-daemon --introspect > org.freedesktop.RealtimeKit1.xml

%install
%makeinstall
install -D org.freedesktop.RealtimeKit1.xml $RPM_BUILD_ROOT/%{_datadir}/dbus-1/interfaces/org.freedesktop.RealtimeKit1.xml

%clean
rm -rf $RPM_BUILD_ROOT

%preun
%if 0%{?has_systemd}
%service_del_preun rtkit-daemon.service
%endif

%pre
groupadd -r rtkit &>/dev/null || :
/usr/bin/id rtkit >/dev/null 2>&1 || \
        useradd -r -g rtkit -c 'RealtimeKit' -s /bin/false -d /proc rtkit

%if 0%{?has_systemd}
%service_add_pre rtkit-daemon.service
%endif

%post
dbus-send --system --type=method_call --dest=org.freedesktop.DBus / org.freedesktop.DBus.ReloadConfig >/dev/null 2>&1 || :
%if 0%{?has_systemd}
%service_add_post rtkit-daemon.service
%endif

%postun
%if 0%{?has_systemd}
%service_del_postun rtkit-daemon.service
%endif

%files
%defattr(0644,root,root,0755)
%doc README GPL LICENSE rtkit.c rtkit.h
%attr(0755,root,root) %{_sbindir}/rtkitctl
%dir %{_libexecdir}/rtkit
%attr(0755,root,root) %{_libexecdir}/rtkit/rtkit-daemon
%{_datadir}/dbus-1/system-services/org.freedesktop.RealtimeKit1.service
%{_datadir}/dbus-1/interfaces/org.freedesktop.RealtimeKit1.xml
%{_datadir}/polkit-1/actions/org.freedesktop.RealtimeKit1.policy
%{_sysconfdir}/dbus-1/system.d/org.freedesktop.RealtimeKit1.conf
%{_mandir}/man8/rtkitctl.*
%if 0%{?has_systemd}
%{_unitdir}/rtkit-daemon.service
%endif

%changelog
* Thu Feb 27 2014 meissner@suse.com
- disable the Cpu ControlGroup entry, as it is currently unsupported
  by systemd. bnc#847948
* Fri Sep 27 2013 sreeves@suse.com
- Add rtkit-bnc836939.patch
  Fix bnc#836939 - use of insecure polkit DBUS API. CVE-2013-4326
* Wed Oct 17 2012 fcrozat@suse.com
- Don't buildrequires systemd, it is pulled by
  pkgconfig(libsystemd-daemon), fixes conflict when bootstrapping
  with systemd-mini packages.
* Sun Sep 23 2012 crrodriguez@opensuse.org
- rtkit-use-system-sd-daemon.patch Use system sddaemon libs.
* Sun Sep 23 2012 crrodriguez@opensuse.org
- Update to version 0.11.x, not much has changed other
  than systemd related updates/improvements.
* Tue Dec 20 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Thu Dec  8 2011 coolo@suse.com
- fix license to be in spdx.org format
* Fri Dec  2 2011 crrodriguez@opensuse.org
- Update to version 0.10.x
  * fix annoying warning
  Failed to make ourselves RT: Invalid argument [bnc#551777]
  * activation is now done with systemd if possible
* Sun Oct 31 2010 jengelh@medozas.de
- Use %%_smp_mflags
* Mon Jan 25 2010 sreeves@novell.com
- Update to version 0.5
  + By default don't demote unknown threads
- bnc#572989 - change to /bin/false
* Fri Aug 14 2009 sreeves@novell.com
- Initial package
